@@ -33,8 +33,16 @@
 #include <string.h>
 #include <unistd.h>
 
+#ifdef HAVE_PCRE2
 #ifdef HAVE_PCRE
-#include <pcre.h>
+#error HAVE_PCRE and HAVE_PCRE2 may not be defined simultaneously
+#endif
+
+#include "confget_pcre2.h"
+#endif
+
+#ifdef HAVE_PCRE
+#include "confget_pcre.h"
 #endif
 
 #include "confget.h"
@@ -103,13 +111,17 @@ bool			 qfeature;
 bool			 qfeatures;
 /* Shell-quote the variable values? */
 static bool		 Sflag;
-#ifdef HAVE_PCRE
+
+#if defined(HAVE_PCRE) || defined(HAVE_PCRE2)
 /* Treat patterns as regular expressions? */
 static bool		 xflag;
 
-static const pcre	*x_matchvalue, **x_margv;
+static const var_pcre	*x_matchvalue, **x_margv;
+
+#if defined(HAVE_PCRE)
 static const pcre_extra	*x_matchvalue_extra, **x_margv_extra;
 #endif
+#endif
 
 /***
  * Function:
@@ -289,7 +301,7 @@ init(const int argc, char * const * const argv)
 				break;
 
 			case 'x':
-#ifdef HAVE_PCRE
+#if defined(HAVE_PCRE) || defined(HAVE_PCRE2)
 				xflag = true;
 				break;
 #else
@@ -333,6 +345,15 @@ init(const int argc, char * const * const argv)
 	margv = argv + optind;
 	const char * const features[][2] = {
 		{ "BASE", VERSION_STRING },
+#if defined(HAVE_PCRE) || defined(HAVE_PCRE2)
+		{"REGEX", "1.0"},
+#if defined(HAVE_PCRE)
+		{"REGEX_IMPL_C_PCRE", CONFGET_REGEX_IMPL_PCRE(PCRE_MAJOR, PCRE_MINOR)},
+#endif
+#if defined(HAVE_PCRE2)
+		{"REGEX_IMPL_C_PCRE2", CONFGET_REGEX_IMPL_PCRE2(PCRE2_MAJOR, PCRE2_MINOR)},
+#endif
+#endif
 		{ NULL, NULL },
 	};
 	if (qsections + qfeature + qfeatures + lflag + Lflag +
@@ -383,40 +404,23 @@ init(const int argc, char * const * const argv)
 		showvarname = false;
 	}
 
-#ifdef HAVE_PCRE
+#if defined(HAVE_PCRE) || defined(HAVE_PCRE2)
 	if (xflag) {
-		if (matchvalue) {
-			const char *pcre_err;
-			int pcre_ofs;
-			x_matchvalue = pcre_compile(matchvalue, 0, &pcre_err,
-			    &pcre_ofs, NULL);
-			if (pcre_err != NULL)
-				errx(1, "Invalid match value: %s", pcre_err);
-			x_matchvalue_extra = pcre_study(x_matchvalue, 0,
-			    &pcre_err);
-			if (pcre_err != NULL)
-				errx(1, "Invalid match value: %s", pcre_err);
-		} else {
+		if (matchvalue)
+			do_pcre_compile(matchvalue, &x_matchvalue, &x_matchvalue_extra, "value");
+		else
 			x_matchvalue = NULL;
-		}
+
 		x_margv = malloc(margc * sizeof(*x_margv));
 		if (x_margv == NULL)
 			err(1, "Could not allocate memory");
+#if defined(HAVE_PCRE)
 		x_margv_extra = malloc(margc * sizeof(*x_margv_extra));
 		if (x_margv_extra == NULL)
 			err(1, "Could not allocate memory");
-		for (size_t t = 0; t < (size_t)margc; t++) {
-			const char *pcre_err;
-			int pcre_ofs;
-			x_margv[t] = pcre_compile(margv[t], 0, &pcre_err,
-			    &pcre_ofs, NULL);
-			if (pcre_err != NULL)
-				errx(1, "Invalid match pattern: %s", pcre_err);
-			x_margv_extra[t] = pcre_study(x_margv[t], 0,
-			    &pcre_err);
-			if (pcre_err != NULL)
-				errx(1, "Invalid match pattern: %s", pcre_err);
-		}
+#endif
+		for (size_t t = 0; t < (size_t)margc; t++)
+			do_pcre_compile(margv[t], &x_margv[t], &x_margv_extra[t], "pattern");
 	}
 #endif
 
@@ -538,17 +542,12 @@ foundvar(const char * const sec, const char * const name,
 		bool found = false;
 		for (int i = 0; i < margc; i++)
 			if (Lflag) {
-#ifdef HAVE_PCRE
+#if defined(HAVE_PCRE) || defined(HAVE_PCRE2)
 				if (xflag) {
-					const int r = pcre_exec(x_margv[i],
-					    x_margv_extra[i], name,
-					    strlen(name), 0, 0, NULL, 0);
-					if (r == 0) {
+					if (do_pcre_match(x_margv[i], x_margv_extra[i], name, margv[i])) {
 						found = true;
 						break;
 					}
-					if (r != PCRE_ERROR_NOMATCH)
-						errx(1, "Could not match '%s' against the '%s' pattern", name, margv[i]);
 				} else
 #endif
 				if (fnmatch(margv[i], name, 0) == 0) {
@@ -567,14 +566,10 @@ foundvar(const char * const sec, const char * const name,
 
 	bool display = true;
 	if (matchvalue != NULL) {
-#ifdef HAVE_PCRE
+#if defined(HAVE_PCRE) || defined(HAVE_PCRE2)
 		if (xflag) {
-			const int r = pcre_exec(x_matchvalue, x_matchvalue_extra, value,
-			    strlen(value), 0, 0, NULL, 0);
-			if (r == PCRE_ERROR_NOMATCH)
+			if (!do_pcre_match(x_matchvalue, x_matchvalue_extra, value, matchvalue))
 				display = false;
-			else if (r != 0)
-				errx(1, "Could not match '%s' against the '%s' pattern", value, matchvalue);
 		} else
 #endif
 		if (fnmatch(matchvalue, value, 0) == FNM_NOMATCH)
