@@ -1,4 +1,4 @@
-# Copyright (c) 2018 - 2021  Peter Pentchev
+# Copyright (c) 2018 - 2022  Peter Pentchev
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -37,7 +37,7 @@ from . import format as fmt
 from . import read_ini_file
 
 try:
-    from typing import List, Optional  # noqa: H301
+    from typing import List, Optional
 
     _TYPING_USED = (defs, List, Optional)
 except ImportError:
@@ -104,10 +104,7 @@ def features(name):
     if name is None:
         print(
             " ".join(
-                [
-                    "{name}={version}".format(name=item[0], version=item[1])
-                    for item in defs.FEATURES
-                ]
+                ["{name}={version}".format(name=item[0], version=item[1]) for item in defs.FEATURES]
             )
         )
     else:
@@ -159,10 +156,7 @@ def validate_options(args, backend_name):
         sys.exit("No variables specified to query")
 
     if query_sections and backend_name != "ini":
-        sys.exit(
-            "The query for sections is only supported for "
-            "the 'ini' backend for the present"
-        )
+        sys.exit("The query for sections is only supported for the 'ini' backend for the present")
 
 
 def check_option_conflicts(args):
@@ -172,10 +166,7 @@ def check_option_conflicts(args):
         int(args.query is not None)
         + int(args.match_var_names)
         + int(args.list_all)
-        + int(
-            bool(args.varnames)
-            and not (args.match_var_names or args.query == "feature")
-        )
+        + int(bool(args.varnames) and not (args.match_var_names or args.query == "feature"))
     )
     if total > 1:
         sys.exit("Only a single query at a time, please!")
@@ -195,7 +186,7 @@ def parse_args():
         "-c",
         action="store_true",
         dest="check_only",
-        help="check whether the variables are defined in " "the file",
+        help="check whether the variables are defined in the file",
     )
     parser.add_argument(
         "-f",
@@ -219,8 +210,7 @@ def parse_args():
         "-m",
         type=str,
         dest="match_var_values",
-        help="only display variables with values that match "
-        "the specified pattern",
+        help="only display variables with values that match the specified pattern",
     )
     parser.add_argument(
         "-N",
@@ -294,9 +284,7 @@ def parse_args():
         dest="match_regex",
         help="treat the match patterns as regular expressions",
     )
-    parser.add_argument(
-        "varnames", nargs="*", help="the variable names to query"
-    )
+    parser.add_argument("varnames", nargs="*", help="the variable names to query")
 
     args = parser.parse_args()
     if args.version:
@@ -341,16 +329,10 @@ def parse_args():
     )
 
     matched_backends = [
-        name
-        for name in sorted(backend.BACKENDS.keys())
-        if name.startswith(args.backend)
+        name for name in sorted(backend.BACKENDS.keys()) if name.startswith(args.backend)
     ]
     if not matched_backends:
-        sys.exit(
-            'Unknown backend "{name}", use "list" for a list'.format(
-                name=args.backend
-            )
-        )
+        sys.exit('Unknown backend "{name}", use "list" for a list'.format(name=args.backend))
     elif len(matched_backends) > 1:
         sys.exit(
             'Ambiguous backend "{name}": {lst}'.format(
