@@ -28,7 +28,7 @@ from . import abstract
 from . import ini
 
 try:
-    from typing import Dict, Type  # noqa: H301
+    from typing import Dict, Type
 
     _TYPING_USED = (Dict, Type, abstract)
 except ImportError:
