@@ -1,4 +1,4 @@
-# Copyright (c) 2018 - 2021  Peter Pentchev <roam@ringlet.net>
+# Copyright (c) 2018 - 2022  Peter Pentchev <roam@ringlet.net>
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -34,7 +34,7 @@ from . import abstract
 
 try:
     from typing import (
-        Callable,  # noqa: H301
+        Callable,
         Dict,
         Match,
         NamedTuple,
@@ -60,9 +60,7 @@ try:
 except ImportError:
     import collections
 
-    MatcherType = collections.namedtuple(  # type: ignore
-        "MatcherType", ["regex", "handle"]
-    )
+    MatcherType = collections.namedtuple("MatcherType", ["regex", "handle"])  # type: ignore
 
 
 class INIBackend(abstract.Backend):
@@ -168,9 +166,7 @@ class INIBackend(abstract.Backend):
         else:
             insrc = self._cfg.filename
             closefd = True
-        with io.open(
-            insrc, mode="r", encoding=self.encoding, closefd=closefd
-        ) as infile:
+        with io.open(insrc, mode="r", encoding=self.encoding, closefd=closefd) as infile:
             for line in infile:
                 line = line.rstrip("\r\n")
                 if state["cont"]:
