@@ -1,4 +1,4 @@
-# Copyright (c) 2018 - 2020  Peter Pentchev <roam@ringlet.net>
+# Copyright (c) 2018 - 2020, 2022  Peter Pentchev <roam@ringlet.net>
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -29,7 +29,7 @@ import re
 
 try:
     from typing import (
-        Callable,  # noqa: H301
+        Callable,
         Dict,
         Iterable,
         NamedTuple,
@@ -121,9 +121,7 @@ class FormatConfig(defs.Config):
             varnames=repr(self.varnames),
             attrs=", ".join(
                 [
-                    "{name}={value}".format(
-                        name=name, value=repr(getattr(self, name))
-                    )
+                    "{name}={value}".format(name=name, value=repr(getattr(self, name)))
                     for name in [
                         "filename",
                         "list_all",
@@ -211,16 +209,12 @@ def filter_vars(cfg, data):
 
         value = sect_data[name]
         if cfg.shell_escape:
-            output_value = "'{esc}'".format(
-                esc="'\"'\"'".join(value.split("'"))
-            )
+            output_value = "'{esc}'".format(esc="'\"'\"'".join(value.split("'")))
         else:
             output_value = value
 
         if cfg.show_var_name:
-            output_full = "{name}={value}".format(
-                name=output_name, value=output_value
-            )
+            output_full = "{name}={value}".format(name=output_name, value=output_value)
         else:
             output_full = output_value
 
