@@ -1,4 +1,4 @@
-# Copyright (c) 2018 - 2021  Peter Pentchev <roam@ringlet.net>
+# Copyright (c) 2018 - 2022  Peter Pentchev <roam@ringlet.net>
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -36,7 +36,7 @@ from . import util
 
 
 try:
-    from typing import Any, Dict, Iterable, List, Optional, Type  # noqa: H301
+    from typing import Any, Dict, Iterable, List, Optional, Type
 
     _TYPING_USED = (Any, Dict, Iterable, List, Optional, Type)
 except ImportError:
@@ -60,9 +60,7 @@ CMDLINE_OPTIONS = {
 def get_test_path(relpath):
     # type: (Optional[str]) -> str
     """Get the path to a test definition file."""
-    return os.environ.get("TESTDIR", "test_data") + (
-        "/" + relpath if relpath is not None else ""
-    )
+    return os.environ.get("TESTDIR", "test_data") + ("/" + relpath if relpath is not None else "")
 
 
 @six.add_metaclass(abc.ABCMeta)
@@ -73,17 +71,13 @@ class XFormType(object):
     def command(self):
         # type: (XFormType) -> str
         """Get the shell command to transform the confget output."""
-        raise NotImplementedError(
-            "{tname}.command".format(tname=type(self).__name__)
-        )
+        raise NotImplementedError("{tname}.command".format(tname=type(self).__name__))
 
     @abc.abstractmethod
     def do_xform(self, res):
         # type: (XFormType, Iterable[cformat.FormatOutput]) -> str
         """Transform the Python representation of the result."""
-        raise NotImplementedError(
-            "{tname}.do_xform()".format(tname=type(self).__name__)
-        )
+        raise NotImplementedError("{tname}.do_xform()".format(tname=type(self).__name__))
 
 
 class XFormNone(XFormType):
@@ -139,21 +133,9 @@ class XFormCountLines(XFormType):
         # type: (XFormCountLines, Iterable[cformat.FormatOutput]) -> str
         if self.sought:
             return str(
-                len(
-                    [
-                        line
-                        for line in res
-                        if self.sought_in == (self.sought in line.output_full)
-                    ]
-                )
+                len([line for line in res if self.sought_in == (self.sought in line.output_full)])
             )
-        return str(
-            len(
-                [  # pylint: disable=unnecessary-comprehension
-                    line for line in res
-                ]
-            )
-        )
+        return str(len([line for line in res]))  # pylint: disable=unnecessary-comprehension
 
 
 XFORM = {
@@ -177,25 +159,19 @@ class OutputDef(object):
     def get_check(self):
         # type: (OutputDef) -> str
         """Get the check string as a shell command."""
-        raise NotImplementedError(
-            "{name}.get_check()".format(name=type(self).__name__)
-        )
+        raise NotImplementedError("{name}.get_check()".format(name=type(self).__name__))
 
     @abc.abstractproperty  # pylint: disable=deprecated-decorator
     def var_name(self):
         # type: (OutputDef) -> str
         """Get the variable name to display."""
-        raise NotImplementedError(
-            "{name}.var_name".format(name=type(self).__name__)
-        )
+        raise NotImplementedError("{name}.var_name".format(name=type(self).__name__))
 
     @abc.abstractmethod
     def check_result(self, _res):
         # type: (OutputDef, str) -> None
         """Check whether the processed confget result is correct."""
-        raise NotImplementedError(
-            "{name}.check_result()".format(name=type(self).__name__)
-        )
+        raise NotImplementedError("{name}.check_result()".format(name=type(self).__name__))
 
 
 class ExactOutputDef(OutputDef):
@@ -232,9 +208,7 @@ class ExitOKOutputDef(OutputDef):
 
     def get_check(self):
         # type: (ExitOKOutputDef) -> str
-        return '[ "$res" {compare} 0 ]'.format(
-            compare="=" if self.success else "!="
-        )
+        return '[ "$res" {compare} 0 ]'.format(compare="=" if self.success else "!=")
 
     @property
     def var_name(self):
@@ -295,11 +269,7 @@ class SingleTestDef:
             data["filename"] = "-"
 
         data["show_var_name"] = "show_var_name" in self.args or (
-            (
-                "match_var_names" in self.args
-                or "list_all" in self.args
-                or len(self.keys) > 1
-            )
+            ("match_var_names" in self.args or "list_all" in self.args or len(self.keys) > 1)
             and "hide_var_name" not in self.args
         )
 
