@@ -1,4 +1,4 @@
-# Copyright (c) 2018 - 2021  Peter Pentchev <roam@ringlet.net>
+# Copyright (c) 2018 - 2022  Peter Pentchev <roam@ringlet.net>
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -32,7 +32,7 @@ import os
 from . import test_defs as tdefs
 
 try:
-    from typing import Any, Dict  # noqa: H301
+    from typing import Any, Dict
 
     TESTING_USED = (tdefs, Any, Dict)
 except ImportError:
@@ -56,9 +56,7 @@ def _load_test_v2(data, _version):
         if "exact" in test["output"]:
             raw["output"] = tdefs.ExactOutputDef(exact=test["output"]["exact"])
         elif "exit" in test["output"]:
-            raw["output"] = tdefs.ExitOKOutputDef(
-                success=test["output"]["exit"]
-            )
+            raw["output"] = tdefs.ExitOKOutputDef(success=test["output"]["exit"])
         else:
             raise ValueError("test output: " + repr(test["output"]))
 
@@ -97,12 +95,5 @@ def load_all_tests(testdir):
     # type: (str) -> Dict[str, tdefs.FileDef]
     """Load all the tests in the defs/tests/ subdirectory."""
     tdir = testdir + "/defs/tests/"
-    filenames = sorted(
-        fname for fname in os.listdir(tdir) if fname.endswith(".json")
-    )
-    return dict(
-        [
-            (os.path.splitext(fname)[0], load_test(tdir + fname))
-            for fname in filenames
-        ]
-    )
+    filenames = sorted(fname for fname in os.listdir(tdir) if fname.endswith(".json"))
+    return dict([(os.path.splitext(fname)[0], load_test(tdir + fname)) for fname in filenames])
