@@ -1,4 +1,4 @@
-# Copyright (c) 2018 - 2021  Peter Pentchev <roam@ringlet.net>
+# Copyright (c) 2018 - 2022  Peter Pentchev <roam@ringlet.net>
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -61,10 +61,7 @@ FULL_TEST_DATA_BEFORE_RIF = [
     for fname, idx, test in sorted(
         itertools.chain(
             *[
-                [
-                    (tfile[0], idx, test)
-                    for idx, test in enumerate(tfile[1].tests)
-                ]
+                [(tfile[0], idx, test) for idx, test in enumerate(tfile[1].tests)]
                 for tfile in TESTS.items()
             ]
         )
@@ -85,7 +82,6 @@ SKIP_ARGS = set(["check_only"])
 
 @ddt.ddt
 class TestStuff(unittest.TestCase):
-    # pylint: disable=no-self-use
     """Run the tests using the Python library."""
 
     @ddt.data(*FULL_TEST_DATA)
