@@ -14,8 +14,8 @@
 //! };
 //! ```
 
-/**
- * Copyright (c) 2021  Peter Pentchev <roam@ringlet.net>
+/*
+ * Copyright (c) 2021, 2022  Peter Pentchev <roam@ringlet.net>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -39,13 +39,13 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  */
-use std::error;
-use std::fmt;
+use std::error::Error;
+use std::fmt::{Display, Formatter, Result as FormatResult};
 use std::str::FromStr;
 
 /// A list of features supported by the confget library.
 pub const FEATURES: [(&str, &str); 3] = [
-    ("BASE", "4.1.0"),
+    ("BASE", env!("CARGO_PKG_VERSION")),
     ("REGEX", "1.0"),
     ("REGEX_IMPL_RUST_CRATE_REGEX", "1"),
 ];
@@ -57,23 +57,27 @@ pub struct ConfgetError {
     msg: String,
 }
 
-impl fmt::Display for ConfgetError {
-    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+impl Display for ConfgetError {
+    #[inline]
+    fn fmt(&self, f: &mut Formatter<'_>) -> FormatResult {
         write!(f, "{}", self.msg)
     }
 }
 
-impl error::Error for ConfgetError {}
+impl Error for ConfgetError {}
 
 impl ConfgetError {
     /// Return a `Box` containing an error object.
-    pub fn boxed(msg: String) -> Box<dyn error::Error> {
+    #[inline]
+    #[must_use]
+    pub fn boxed(msg: String) -> Box<dyn Error> {
         Box::new(Self { msg })
     }
 }
 
 /// The configuration backend to use for parsing the input data.
-#[derive(Debug)]
+#[derive(Debug, PartialEq, Eq)]
+#[non_exhaustive]
 pub enum BackendKind {
     /// Parse INI-style files and their sections.
     Ini,
@@ -87,9 +91,10 @@ impl BackendKind {
 impl FromStr for BackendKind {
     type Err = ConfgetError;
 
+    #[inline]
     fn from_str(s: &str) -> Result<Self, Self::Err> {
         match s {
-            BackendKind::INI => Ok(BackendKind::Ini),
+            Self::INI => Ok(Self::Ini),
             other => Err(ConfgetError {
                 msg: format!("unrecognized backend type '{}'", other),
             }),
@@ -98,9 +103,10 @@ impl FromStr for BackendKind {
 }
 
 impl AsRef<str> for BackendKind {
+    #[inline]
     fn as_ref(&self) -> &str {
         match self {
-            BackendKind::Ini => BackendKind::INI,
+            &Self::Ini => Self::INI,
         }
     }
 }
@@ -108,12 +114,14 @@ impl AsRef<str> for BackendKind {
 /// Configuration settings for the `confget` functions.
 ///
 /// This is the main way to control the behavior of a backend's
-/// [read_file][`crate::backend::Backend::read_file`] method,
-/// the [read_ini_file][`crate::read_ini_file`] function, and
-/// the [format::filter_vars][`crate::format::filter_vars`] function:
+/// [`read_file`][`crate::backend::Backend::read_file`] method,
+/// the [`read_ini_file`][`crate::read_ini_file`] function, and
+/// the [`format::filter_vars`][`crate::format::filter_vars`] function:
 /// specify what file to read, what variables to extract from it, and
 /// how to format them.
 #[derive(Debug)]
+#[allow(clippy::exhaustive_structs)]
+#[allow(clippy::struct_excessive_bools)]
 pub struct Config {
     /// The configuration backend to use.
     pub backend: BackendKind,
@@ -157,6 +165,7 @@ impl Default for Config {
     ///
     /// This is the recommended way to use the [`Config`] struct:
     /// only override the settings that must be overridden.
+    #[inline]
     fn default() -> Self {
         Self {
             backend: BackendKind::Ini,
@@ -165,9 +174,9 @@ impl Default for Config {
             match_regex: false,
             match_var_names: false,
             match_var_values: None,
-            name_prefix: "".to_string(),
-            name_suffix: "".to_string(),
-            section: "".to_string(),
+            name_prefix: String::new(),
+            name_suffix: String::new(),
+            section: String::new(),
             section_override: false,
             section_specified: false,
             shell_escape: false,
@@ -179,6 +188,8 @@ impl Default for Config {
 
 impl Config {
     /// A deprecated alias for [`Config::default()`].
+    #[inline]
+    #[must_use]
     pub fn get_default() -> Self {
         Self::default()
     }
