@@ -11,26 +11,27 @@
 //!
 //! # Quick-and-easy parsing of INI-style files
 //!
-//! The [read_ini_file][`crate::read_ini_file`] function will parse
+//! The [`read_ini_file`] function will parse
 //! an INI-style file and return a hashmap of the values found in its
 //! various sections, as well as the name of the first section found in
 //! the file (or the one specified in the configuration if
-//! the [section_override][`crate::defs::Config::section_override`] option
-//! is enabled).
+//! the [`Config::section_override`] option is enabled).
 //!
 //! ```
-//! # use std::error;
+//! # use std::error::Error;
 //! # use std::fs;
-//! # use std::path;
+//! # use std::path::Path;
 //!
-//! # fn main() -> Result<(), Box<dyn error::Error>> {
+//! # use confget::Config;
+//!
+//! # fn main() -> Result<(), Box<dyn Error>> {
 //! # let tempd_obj = tempfile::tempdir()?;
-//! # let confdir: &path::Path = tempd_obj.as_ref();
+//! # let confdir: &Path = tempd_obj.as_ref();
 //! # fs::write(&confdir.join("config.ini"), "var = value\n");
 //! // Default configuration except for the filename.
-//! let config = confget::Config {
+//! let config = Config {
 //!     filename: Some(confdir.join("config.ini").to_str().unwrap().to_string()),
-//!     ..confget::Config::default()
+//!     ..Config::default()
 //! };
 //! let (data, first_section) = confget::read_ini_file(&config)?;
 //! # Ok(())
@@ -41,9 +42,9 @@
 //! the [CHANGES](https://gitlab.com/confget/confget/-/blob/master/CHANGES)
 //! file in the source distribution.
 
-#![doc(html_root_url = "https://docs.rs/confget/4.1.0")]
-/**
- * Copyright (c) 2021  Peter Pentchev <roam@ringlet.net>
+#![doc(html_root_url = "https://docs.rs/confget/4.1.1")]
+/*
+ * Copyright (c) 2021, 2022  Peter Pentchev <roam@ringlet.net>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -67,38 +68,50 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  */
-use std::error;
+// We want to re-export some defs::* types to make it easier on the consumers.
+#![allow(clippy::pub_use)]
 
-use crate::backend::Backend;
+use std::error::Error;
+
+use crate::backend::ini::IniBackend;
+use crate::backend::{Backend, DataRead};
 
 pub mod backend;
 pub mod defs;
 pub mod format;
 
-pub use defs::{ConfgetError, Config};
+pub use defs::{BackendKind, ConfgetError, Config};
 
 /// Construct an object of the specified backend type.
 ///
-/// The `backend` member of the [Config][`crate::defs::Config`] object
+/// The `backend` member of the [`Config`] object
 /// specifies the type of the backend to construct.
 ///
 /// Some backends may perform validation at object creation time;
 /// the "ini" one currently does not, so this method will always succeed.
-pub fn get_backend<'a>(
-    config: &'a defs::Config,
-) -> Result<Box<dyn backend::Backend + 'a>, Box<dyn error::Error>> {
+///
+/// # Errors
+///
+/// None for the present, but future backends may check for configuration
+/// inconsistencies.
+#[inline]
+pub fn get_backend<'cfg>(config: &'cfg Config) -> Result<Box<dyn Backend + 'cfg>, Box<dyn Error>> {
     match config.backend {
-        defs::BackendKind::Ini => Ok(Box::new(backend::ini::IniBackend { config })),
+        BackendKind::Ini => Ok(Box::new(IniBackend { config })),
     }
 }
 
 /// Read an INI-style file with the specified configuration.
 ///
 /// Internally constructs an "ini" backend and invokes its
-/// [read_file][`crate::backend::Backend::read_file`] method.
-/// The [Config][`crate::defs::Config`] object's `filename`
-/// member must contain a value.
-pub fn read_ini_file(config: &defs::Config) -> Result<backend::DataRead, Box<dyn error::Error>> {
-    let ini = backend::ini::IniBackend { config };
+/// [`Backend::read_file`] method.
+/// The [`Config`] object's `filename` member must contain a value.
+///
+/// # Errors
+///
+/// The same as from [`IniBackend::read_file`].
+#[inline]
+pub fn read_ini_file(config: &Config) -> Result<DataRead, Box<dyn Error>> {
+    let ini = IniBackend { config };
     ini.read_file()
 }
