@@ -72,9 +72,7 @@ if [ ! -f "$TESTDIR/{fname}" ]; then
 fi"""
 
 
-def add_cmdline_options(
-    cmdline: List[str], test: t_defs.SingleTestDef
-) -> None:
+def add_cmdline_options(cmdline: List[str], test: t_defs.SingleTestDef) -> None:
     """Add the options from test.args into cmdline."""
     for name, value in test.args.items():
         option = t_defs.CMDLINE_OPTIONS[name]
@@ -97,11 +95,7 @@ def main() -> None:
             print(PRELUDE.format(count=len(data.tests)), file=testf)
 
             filenames = sorted(
-                {
-                    test.args["filename"]
-                    for test in data.tests
-                    if "filename" in test.args
-                }
+                {test.args["filename"] for test in data.tests if "filename" in test.args}
             )
             for filename in filenames:
                 print(CHECK_TESTFILE.format(fname=filename), file=testf)
@@ -118,9 +112,7 @@ def main() -> None:
                 add_cmdline_options(cmdline, test)
 
                 if test.stdin is not None:
-                    cmdline.extend(
-                        [t_defs.CMDLINE_OPTIONS["filename"][0], "-"]
-                    )
+                    cmdline.extend([t_defs.CMDLINE_OPTIONS["filename"][0], "-"])
 
                 cmdline.extend([f"'{key}'" for key in test.keys])
 
